@@ -23,7 +23,7 @@ char vbuf_hint[MAX_LINELEN+1];
 char vbuf_help[MAX_LINELEN+1];
 char vbuf_solution[MAX_LINELEN+1];
 char vbuf_latex[MAX_LINELEN+1];
-char vbuf_css[MAX_LINELEN+1];
+const size_t MAX_KEY_LEN=128;
 
 #include "sp.c"
 
@@ -37,6 +37,21 @@ void p_author(char *p[MAX_PARM])
     fprintf(outf,"author=%s\n",p[0]);
 }
 
+static void p_keyword(char *p[MAX_PARM], const char *key)
+{
+    p[0]=find_word_start(p[0]);
+    if(strlen(p[0])>MAX_KEY_LEN) p[0][MAX_KEY_LEN]=0;
+    fprintf(outf,"%s=%s\n", key, p[0]);
+}
+
+void p_title_ca(char *p[MAX_PARM]) { p_keyword(p, "title_ca"); }
+void p_title_cn(char *p[MAX_PARM]) { p_keyword(p, "title_cn"); }
+void p_title_en(char *p[MAX_PARM]) { p_keyword(p, "title_en"); }
+void p_title_es(char *p[MAX_PARM]) { p_keyword(p, "title_es"); }
+void p_title_it(char *p[MAX_PARM]) { p_keyword(p, "title_it"); }
+void p_title_nl(char *p[MAX_PARM]) { p_keyword(p, "title_nl"); }
+void p_title_si(char *p[MAX_PARM]) { p_keyword(p, "title_si"); }
+
 void p_email(char *p[MAX_PARM])
 {
     p[0]=find_word_start(p[0]);
@@ -69,6 +84,17 @@ void p_css(char *p[MAX_PARM])
     snprintf(vbuf_css,sizeof(vbuf_css),"%s",p[0]); subst(vbuf_css);
 	fprintf(outf,"oefcss=%s\n",vbuf_css); 
 }
+
+void p_credits(char *p[MAX_PARM])
+{
+    char vbuf_credits[MAX_LINELEN+1];
+    if(p==NULL) return;
+    snprintf(vbuf_credits,sizeof(vbuf_credits),"%s",p[0]); 
+    subst(vbuf_credits);
+	singlespace(vbuf_credits);
+	fprintf(outf,"credits=%s\n\n", vbuf_credits);
+}
+
 /* */
 
 void p_wims(char *p[MAX_PARM])
@@ -343,10 +369,10 @@ void p_answer(char *p[MAX_PARM])
 	if(i<1) {	/* unused name; the answer should be analyzed */
 	    char *pm;
 	    pm=xmalloc(MAX_NAMELEN+2);
-	    strcpy(pm,vbuf); param[varcnt].name=pm;
+	    ovlstrcpy(pm,vbuf); param[varcnt].name=pm;
 	    if(pt) {
 		*pt=';'; 
-		strcpy(vbuf,pt); subst(vbuf); pt=vbuf;
+		ovlstrcpy(vbuf,pt); subst(vbuf); pt=vbuf;
 	    }
 	    else pt="";
 	    param[varcnt].type=pt_real;
@@ -483,7 +509,7 @@ void parm(char *p[MAX_PARM], int ptype)
     for(pp=p[0];*pp;pp++) if(!isalnum(*pp) && *pp!='_') {
 	/* bad name and security risk */
 	if(!isspace(*pp)) return;
-	strcpy(pp,pp+1); pp--;
+	ovlstrcpy(pp,pp+1); pp--;
     }
     for(i=1;i<varcnt && strcmp(p[0],param[i].name)!=0;i++);
     p[1]=find_word_start(p[1]);
@@ -608,14 +634,14 @@ void p_plot(char *p[MAX_PARM])
 	    p2=find_word_start(p[i]);
 	    if(*p2=='x' || *p2=='X') xr=i;
 	    else if (*p2=='y' || *p2=='Y') yr=i;
-	    strcpy(p[i],pp);
+	    ovlstrcpy(p[i],pp);
 	}
     }
 /*    if(xr>=0 && (pp=strstr(p[xr],".."))!=NULL) {
 	
     }
 */    if(f<0) return;
-    strcpy(buf, p[f]);
+    ovlstrcpy(buf, p[f]);
     prepcnt=0; parmprep(buf,pt_func);
     fprintf(outf,"plot_fn=!rawmath %s\n",buf);
     
