@@ -2162,6 +2162,10 @@ MYFUNCTION calc_routine[]={
       {"ls",		0,	calc_listfile},
       {"mailurl",	0,	calc_mailurl},
       {"makelist",	1,	calc_makelist},
+      {"math2html",	0,	htmlmath},
+      {"math2mathml",	0,mathmlmath},
+      {"math2tex",	0,	texmath},
+      {"mathmlmath",	0,	mathmlmath},
       {"mathsubst",	1,	calc_mathsubst},
       {"mathsubstit",	1,	calc_mathsubst},
       {"mathsubstitute",1,	calc_mathsubst},
