@@ -551,15 +551,16 @@ void _header(char *p, int option)
 </head><body %s %s%s %s>\n",
 	   hbuf,s2,ol,wsbuf2,bo);*/
 	 if(ol[0]) {
-	    output("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\
-	    \n<html><head>%s\n\
+	    output("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\
+	    \n<html xml:lang=\"%s\"\
+	    xmlns=\"http://www.w3.org/1999/xhtml\" xmlns:mathml=\"http://www.w3.org/1998/Math/MathML\"><head>%s\n\
      </head>\n<body %s %s\"%s\" %s>\n",
-	   hbuf,s2,ol,wsbuf2,bo);}
+	   lang,hbuf,s2,ol,wsbuf2,bo);}
 	   else {
-	   output("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\
-	    \n<html><head>%s\n\
+	   output("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\
+	    \n<html xml:lang=\"%s\" xmlns=\"http://www.w3.org/1999/xhtml\" xmlns:mathml=\"http://www.w3.org/1998/Math/MathML\"><head>%s\n\
      </head>\n<body %s %s%s %s>\n",
-	   hbuf,s2,ol,wsbuf2,bo);
+	   lang,hbuf,s2,ol,wsbuf2,bo);
 	   }
     exec_headmenu(p);
     if(option) exec_title(p);
@@ -669,7 +670,7 @@ void exec_restart(char *p)
 	else goto usual;
     }
     printf("Location: %s\r\n\r\n\
-<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\
+<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\
 <html><body><a href=\"%s\">%s</a></body></html>",buf2,buf2,buf2);
     close_working_file(&m_file,0); write_logs();
     snprintf(buf,sizeof(buf),"%ld",nowtime);
@@ -1786,6 +1787,10 @@ MYFUNCTION exec_routine[]={
       {"mailto",	EXEC_MAIL|EXEC_SUBST,	exec_mailto},
       {"mailurl",	EXEC_MAIL|EXEC_SUBST|EXEC_USECALC,calc_mailurl},
       {"makelist",	EXEC_STRING|EXEC_USECALC,calc_makelist},
+      {"math2html",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,htmlmath},
+      {"math2mathml",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,mathmlmath},
+      {"math2tex",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,texmath},
+      {"mathmlmath",	EXEC_STRING|EXEC_SUBST|EXEC_USECALC,mathmlmath},
       {"mathsubst",	EXEC_STRING|EXEC_USECALC,calc_mathsubst},
       {"mathsubstit",	EXEC_STRING|EXEC_USECALC,calc_mathsubst},
       {"mathsubstitute",EXEC_STRING|EXEC_USECALC,calc_mathsubst},
